#!/usr/bin/env python3

import amulet

from base_deploy import BasicMongo


class ShardNode(BasicMongo):
    def __init__(self, series):
        super(ShardNode, self).__init__(units=1,
                                        series=series,
                                        deploy_timeout=900)

    def deploy(self):
        self.d.add('configsvr', charm='mongodb', units=self.units)
        self.d.add('mongos', charm='mongodb', units=self.units)
        self.d.add('shard1', charm='mongodb', units=self.units)
        self.d.add('shard2', charm='mongodb', units=self.units)

        # Setup the config svr
        self.d.configure('configsvr', {'replicaset': 'configsvr'})

        # define each shardset
        self.d.configure('shard1', {'replicaset': 'shard1'})
        self.d.configure('shard2', {'replicaset': 'shard2'})

        self.d.configure('mongos', {})

        # Connect the config servers to mongo shell
        self.d.relate('configsvr:configsvr', 'mongos:mongos-cfg')

        # connect each shard to the mongo shell
        self.d.relate('mongos:mongos', 'shard1:database')
        self.d.relate('mongos:mongos', 'shard2:database')
        self.d.expose('configsvr')
        self.d.expose('mongos')
        super(ShardNode, self).deploy()

        self.sentry_dict = {
                            'config-sentry': self.d.sentry['configsvr'][0],
                            'mongos-sentry': self.d.sentry['mongos'][0],
                            'shard1-sentry': self.d.sentry['shard1'][0],
                            'shard2-sentry': self.d.sentry['shard2'][0]
                            }

    def validate_world_connectivity(self):
        self.addy = self.d.sentry['mongos'][0].info['public-address']
        super(ShardNode, self).validate_world_connectivity()

    def validate_running_services(self):
        super(ShardNode, self).validate_running_services()

    def validate_status_interface(self):
        self.addy = self.sentry_dict['config-sentry'].info['public-address']
        super(ShardNode, self).validate_status_interface()

    def validate_manual_connection(self):
        fmt = "mongo {}"
        addy = self.d.sentry['mongos'][0].info['public-address']
        if ":" in addy:
            fmt = "mongo --ipv6 {}:27017"
        jujuruncmd = fmt.format(addy)
        output, code = self.d.sentry['shard1'][0].run(jujuruncmd)
        if code != 0:
            msg = ("Manual Connection failed, unit shard1:{} code:{} cmd:{}"
                   .format(output, code, jujuruncmd))
            amulet.raise_status(amulet.SKIP, msg=msg)

        output, code = self.d.sentry['shard2'][0].run(jujuruncmd)
        if code != 0:
            msg = ("Manual Connection failed, unit shard2:{} code:{} cmd:{}"
                   .format(output, code, jujuruncmd))
            amulet.raise_status(amulet.SKIP, msg=msg)

    def run(self):
        self.deploy()
        self.validate_world_connectivity()
        self.validate_status_interface()
        self.validate_running_services()
        self.validate_manual_connection()
