#!/usr/bin/env python3

import amulet

from base_deploy import BasicMongo


class TestCeilometer(BasicMongo):
    def __init__(self, series):
        super(TestCeilometer, self).__init__(units=1, series=series,
                                             deploy_timeout=900)

    def deploy(self):
        self.d.add('mongodb', charm='mongodb', units=self.units)
        self.d.add('ceilometer', 'cs:{}/ceilometer'.format(self.series))
        self.d.relate('mongodb:database', 'ceilometer:shared-db')
        self.d.expose('mongodb')
        super(TestCeilometer, self).deploy()

    def validate_world_connectivity(self):
        self.addy = self.d.sentry['mongodb'][0].info['public-address']
        super(TestCeilometer, self).validate_world_connectivity()

    def validate_mongo_relation(self):
        unit = self.d.sentry['ceilometer'][0]
        mongo = self.d.sentry['mongodb'][0].info['public-address']
        mongo_reladdr = self.d.sentry['mongodb'][0].relation(
            'database', 'ceilometer:shared-db')
        cont = unit.file_contents('/etc/ceilometer/ceilometer.conf')
        if (mongo not in cont and mongo_reladdr.get(
                'hostname', 'I SURE HOPE NOT') not in cont):
            amulet.raise_status(amulet.FAIL, "Unable to verify ceilometer cfg")

    def run(self):
        self.deploy()
        self.validate_world_connectivity()
